summaryrefslogtreecommitdiff
path: root/ace/Timer_Heap_T.h
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2002-04-11 12:24:30 +0000
committerJohnny Willemsen <jwillemsen@remedy.nl>2002-04-11 12:24:30 +0000
commit1175a18a9b8b0c28f49c9c67f79fff1aa81c346c (patch)
treeacc085dd1262bb6c9675cb85462574b52686825c /ace/Timer_Heap_T.h
parentc67cd588b7b117c9df0f5f81fcc74d7e2b480f8b (diff)
downloadATCD-1175a18a9b8b0c28f49c9c67f79fff1aa81c346c.tar.gz
ChangeLogTag: Thu Apr 11 14:24:12 2002 Johnny Willemsen <jwillemsen@remedy.nl>
Diffstat (limited to 'ace/Timer_Heap_T.h')
-rw-r--r--ace/Timer_Heap_T.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/ace/Timer_Heap_T.h b/ace/Timer_Heap_T.h
index 6039225e797..5400d89524c 100644
--- a/ace/Timer_Heap_T.h
+++ b/ace/Timer_Heap_T.h
@@ -129,7 +129,7 @@ public:
/**
* Schedule a timer that may optionally auto-reset.
* Schedule <type> that will expire after <delay> amount of time,
* which is specified in absolute time. If it expires then <act> is
* passed in as the value to the <functor>. If <interval> is != to
* <ACE_Time_Value::zero> then it is used to reschedule the <type>
@@ -145,7 +145,7 @@ public:
*/
virtual long schedule (const TYPE &type,
const void *act,
- const ACE_Time_Value &delay,
+ const ACE_Time_Value &future_time,
const ACE_Time_Value &interval = ACE_Time_Value::zero);
/**
@@ -129,7 +129,7 @@ public:
/**
* Schedule a timer that may optionally auto-reset.
- * Schedule <type> that will expire after <delay> amount of time,
+ * Schedule <type> that will expire at <future_time>,
* which is specified in absolute time. If it expires then <act> is
* passed in as the value to the <functor>. If <interval> is != to